from app.models import User
from flask import render_template, request, url_for
from . import bp


@bp.route('/')
def users():
    return render_template(
        'users/users.html.j2',
        title='Users'
    )


@bp.route('/api_users')
def api_users():
    query = User.query

    # search filter
    search = request.args.get('search')
    if search:
        query = query.filter(User.username.like(f'%{search}%') | User.email.like(f'%{search}%'))
    total = query.count()

    # sorting
    sort = request.args.get('sort')
    if sort:
        order = []
        for s in sort.split(','):
            direction = s[0]
            name = s[1:]
            if name not in ['username', 'email']:
                name = 'username'
            col = getattr(User, name)
            if direction == '-':
                col = col.desc()
            order.append(col)
        if order:
            query = query.order_by(*order)

    # pagination
    offset = request.args.get('offset', type=int, default=-1)
    limit = request.args.get('limit', type=int, default=-1)
    if offset != -1 and limit != -1:
        query = query.offset(offset).limit(limit)

    # response
    return {
        'data': [user.to_dict() for user in query],
        'total': total
    }
